@@ -59,18 +59,25 @@ class Video:
 
         return videos
 
-    def get_video(self) -> 'Video':
+    def get(self) -> 'Video':
         response = get(url=f'{VIDEOS}/{self.id}')
 
         return self.from_dict(response.json())
 
+    def query(self, query: str = None) -> List['Video']:
+        querystring = {"q": query}
+
+        response = get(url=VIDEOS, params=querystring)
+        videos = [self.from_dict(video) for video in response.json()['rows']]
+
+        return videos
+
     def create_upload_credentials(self) -> UploadCredentials:
         response = UploadCredentials().create(self.title)
 
         return response
 
     def create_otp(self, ttl: int = 300) -> OTP:
-
         otp = OTP().create(self.id, ttl)
 
         return otp
